@@ -15,11 +15,13 @@
 
 package EBox::OpenVPN;
 use base qw(
-             EBox::GConfModule  EBox::ServiceModule::ServiceInterface
-             EBox::Model::ModelProvider  EBox::Model::CompositeProvider
-           EBox::NetworkObserver  EBox::LogObserver
-           EBox::FirewallObserver EBox::CA::Observer
-           EBox::ServiceModule::ServiceInterface);
+             EBox::Module::Service
+             EBox::Model::ModelProvider
+             EBox::Model::CompositeProvider
+             EBox::NetworkObserver
+             EBox::LogObserver
+             EBox::FirewallObserver
+             EBox::CA::Observer);
 
 use strict;
 use warnings;
@@ -28,10 +30,10 @@ use Perl6::Junction qw(any);
 use Error qw(:try);
 
 use EBox::Gettext;
-use EBox::Summary::Module;
-use EBox::Summary::Status;
 use EBox::Sudo;
 use EBox::Validate;
+use EBox::Dashboard::Section;
+use EBox::Dashboard::Value;
 use EBox::OpenVPN::Server;
 use EBox::OpenVPN::Client;
 use EBox::OpenVPN::Server::ClientBundleGenerator::EBoxToEBox;
@@ -43,6 +45,7 @@ use EBox::NetWrappers qw();
 use EBox::FileSystem;
 
 use Perl6::Junction qw(any);
+use File::Slurp;
 use Error qw(:try);
 
 use constant MAX_IFACE_NUMBER => 999999;  # this is the last number which prints
@@ -64,7 +67,7 @@ sub _create
 {
     my $class = shift;
     my $self =
-      $class->SUPER::_create(name => 'openvpn', printableName => __('openVPN'));
+      $class->SUPER::_create(name => 'openvpn', printableName => __('VPN'));
     bless($self, $class);
     return $self;
 }
@@ -102,7 +105,12 @@ sub compositeClasses
     return [];
 }
 
-sub _regenConfig
+#TODO: this method needs to be splitted in setConf and enforceServiceState
+# but right now some of the methods invoked do both configuration file
+# handling and daemon stopping/running so they need a lot of work. the only
+# drawback of doing this for now is that the hook between setConf and
+# enforceServiceState won't be useful
+sub _enforceServiceState
 {
     my ($self) = @_;
 
@@ -129,7 +137,7 @@ sub _initializeInterfaces
 
 # Method: usedFiles
 #
-#       Override EBox::ServiceModule::ServiceInterface::usedFiles
+#       Override EBox::Module::Service::usedFiles
 #
 sub usedFiles
 {
@@ -163,7 +171,7 @@ sub usedFiles
 
 # Method: enableActions
 #
-#       Override EBox::ServiceModule::ServiceInterface::enableActions
+#       Override EBox::Module::Service::enableActions
 #
 sub enableActions
 {
@@ -172,18 +180,9 @@ sub enableActions
                     );
 }
 
-# Method: serviceModuleName
-#
-#       Override EBox::ServiceModule::ServiceInterface::serviceModuleName
-#
-sub serviceModuleName
-{
-    return 'openvpn';
-}
-
 #  Method: enableModDepends
 #
-#   Override EBox::ServiceModule::ServiceInterface::enableModDepends
+#   Override EBox::Module::Service::enableModDepends
 #
 sub enableModDepends
 {
@@ -238,7 +237,7 @@ sub _writeConfFiles
 
     $self->_writeRIPDaemonConf(); # XXX RIP stuff
 
-    my $confDir = $self->confDir;
+    my $confDir = $self->confDir();
 
     my @daemons = $self->daemons();
     foreach my $daemon (@daemons) {
@@ -252,7 +251,7 @@ sub _prepareLogFiles
     my ($self) = @_;
 
     my $logDir = $self->logDir();
-    for my $name ($self->daemonsNames()) {
+    foreach my $name (@{$self->daemonsNames()}) {
         for my $file ("$logDir/$name.log", "$logDir/status-$name.log") {
             try {
                 EBox::Sudo::root("test -e $file");
@@ -264,6 +263,25 @@ sub _prepareLogFiles
             EBox::Sudo::root("chmod 0640 $file");
         }
     }
+
+    # recreate log rotate configuration file
+    my @logFiles = map {
+        $_->logFile()
+    } $self->daemons();
+
+    my  $fileMode = {
+                     uid  => 0,
+                     gid  => 0,
+                     mode => '0644',
+    };
+
+    EBox::Module::Base::writeConfFileNoCheck('/etc/logrotate.d/ebox-openvpn',
+                         '/openvpn/logrotate.mas',
+                         [
+                          logFiles => \@logFiles,
+                         ],
+                         $fileMode,
+                        )
 }
 
 sub _cleanupDeletedDaemons
@@ -354,7 +372,7 @@ sub daemons
 sub activeDaemons
 {
     my ($self) = @_;
-    return grep { $_->service } $self->daemons();
+    return grep { $_->isEnabled() } $self->daemons();
 }
 
 #
@@ -373,7 +391,7 @@ sub daemonsNames
 
     my @daemonsNames = ($self->serversNames(),$self->clientsNames(),);
 
-    return @daemonsNames;
+    return \@daemonsNames;
 }
 
 # server-related methods
@@ -408,7 +426,7 @@ sub servers
 sub activeServers
 {
     my ($self) = @_;
-    return grep { $_->service } $self->servers();
+    return grep { $_->isEnabled() } $self->servers();
 }
 
 #
@@ -521,7 +539,7 @@ sub clients
 sub activeClients
 {
     my ($self) = @_;
-    return grep { $_->service } $self->clients();
+    return grep { $_->isEnabled() } $self->clients();
 }
 
 #
@@ -631,8 +649,8 @@ sub _serversToConnect
 
 # Method: checkNewDaemonName
 #
-#    Check if the name for a new daemon does nto conflict with the actual
-#    configuration
+#    Check if the name for a new daemon is correct and does not conflicts with
+#    the actual configuration
 #
 #  Parameters:
 #          $name       - name to be checked
@@ -642,6 +660,16 @@ sub checkNewDaemonName
 {
     my ($self, $name, $daemonType, $internal) = @_;
 
+    if (not $name =~ m/^[\w\.\-]+$/) {
+        throw EBox::Exceptions::External(
+            __x(
+              q{Invalid name {name}. Only alpahanumeric  and '-', '_', '.' characters are allowed},
+                name => $name,
+
+            )
+                                        )
+    }
+
     # check if the daemon name is repeated in others daemon types
     if ($daemonType eq 'server') {
         my $clients = $self->model('Clients');
@@ -790,10 +818,10 @@ sub firewallHelper
 {
     my ($self) = @_;
 
-    my $service = $self->service();
+    my $enabled = $self->isEnabled();
 
     # Initialize interfaces before setting fw rules
-    if ($service and EBox::Global->getInstance()->modIsChanged('openvpn')) {
+    if ($enabled and EBox::Global->getInstance()->modIsChanged('openvpn')) {
         $self->_initializeInterfaces();
     }
 
@@ -826,7 +854,7 @@ sub firewallHelper
     my $serversToConnect = $self->_serversToConnect();
 
     my $firewallHelper = new EBox::OpenVPN::FirewallHelper(
-        service          => $service,
+        service          => $enabled,
         ifaces           => \@ifaces,
         ports     => \@ports,
         serversToConnect => $serversToConnect,
@@ -861,19 +889,12 @@ sub CAIsReady
     return $ready;
 }
 
-sub service
-{
-    my ($self) = @_;
-
-    return $self->isEnabled();
-}
-
 sub _doDaemon
 {
     my ($self) = @_;
-    my $running = $self->running();
+    my $running = $self->isRunning();
 
-    if ($self->service) {
+    if ($self->isEnabled()) {
         if ($running) {
             $self->_stopDaemon();
             $self->_startDaemon();
@@ -898,16 +919,15 @@ sub _doDaemon
     }
 }
 
-sub running
+sub isRunning
 {
     my ($self) = @_;
 
     if ($self->_runningInstances()) {
         return 1;
-    }elsif ($self->service) {
-        my @activeUserDaemons =
-          grep { (not $_->service) and (not $_->internal) } $self->daemons;
-        return @activeUserDaemons == 0 ? 1 : 0;
+    }elsif ($self->isEnabled()) {
+        my @activeDaemons = grep { (not $_->isEnabled())  } $self->daemons;
+        return (@activeDaemons == 0) ? 1 : 0;
     }
 
     return 0;
@@ -916,14 +936,27 @@ sub running
 sub userRunning
 {
     my ($self) = @_;
-    my @userDaemons = grep { not $_->internal } $self->daemons;
 
-    foreach my $userDaemon (@userDaemons) {
-        return 1 if $userDaemon->running;
+
+    my $noneDaemonEnabled = 1;
+
+    my @daemons =  $self->daemons;
+    foreach my $daemon (@daemons) {
+        next if $daemon->internal();
+
+        return 1 if $daemon->isRunning();
+
+        if ($daemon->isEnabled()) {
+            $noneDaemonEnabled = 0;
+        }
     }
 
-    return
-      0;   # XXX control that there isn't any user daemon incorrectly running
+
+    if ($noneDaemonEnabled) {
+        return 1 if $self->isEnabled()
+    }
+
+    return 0;   # XXX control that there isn't any user daemon incorrectly running
 }
 
 sub _startDaemon
@@ -931,7 +964,7 @@ sub _startDaemon
     my ($self) = @_;
 
     try {
-        my @daemons =  grep { $_->service   } $self->daemons;
+        my @daemons =  grep { $_->isEnabled() } $self->daemons;
 
         foreach my $daemon (@daemons) {
             $daemon->start();
@@ -961,7 +994,7 @@ sub _runningInstances
 
     my @daemons = $self->daemons();
     foreach my $d (@daemons) {
-        return 1 if $d->running;
+        return 1 if $d->isRunning;
     }
 
     return 0;
@@ -1237,6 +1270,42 @@ sub _anyDaemonReturnsTrue
     return undef;
 }
 
+# Method: newClient
+#
+#    Create a new VPN client from API
+#
+# Positional parameters:
+#
+#    name - String the name to set the VPN client
+#
+# Named parameters:
+#
+#    internal - Boolean indicating whether the client is internal or
+#               not
+#
+#    service - Boolean indicating whether the new client must be up or
+#              not
+#
+#    proto - String the protocol used by client. Options: 'udp' or
+#            'tcp'
+#
+#    servers - Array ref containing tuples with two elements: the VPN
+#              server IP address and the port which is listening to
+#
+#    caCertificate - String the path to the CA certificate
+#
+#    certificate   - String the path to the VPN client certificate
+#
+#    certificateKey - String the path to the VPN client private key
+#    corresponding to the previous certificate
+#
+#    ripPasswd     - String the RIP password to exchange routes with
+#
+# Returns:
+#
+#    <EBox::OpenVPN::Client> - the newly created VPN client daemon
+#    instance
+#
 sub newClient
 {
     my ($self, $name, %params) = @_;
@@ -1244,9 +1313,6 @@ sub newClient
       caCertificate certificate certificateKey
       ripPasswd
       service internal);
-    
-    EBox::debug("PARAMS @_");
-
 
     if (( exists $params{bundle} ) and ($params{bundle})) {
         %params = (
@@ -1259,13 +1325,10 @@ sub newClient
     }
 
     foreach my $param (@paramsNeeded) {
-        EBox::debug("param |$param|");
         exists $params{$param}
           or throw EBox::Exceptions::MissingArgument($param);
     }
 
-    EBox::debug("AAA");
-
     my $client;
     try {
         $client = $self->_doNewClient($name, %params);
@@ -1295,27 +1358,24 @@ sub _doNewClient
 
     # create client
 
-
     my $clients = $self->model('Clients');
 
     my $hidden = $params{internal} ? 1 : 0;
-    $clients->addRow(
-                     name => $name,
-                     internal => $params{internal},
-                     service => 0,
-                     hidden  => $hidden,
-                    );
-
-    EBox::debug("ADDED");
+    my $addedId = $clients->add(
+        name => $name,
+        internal => $params{internal},
+        service => 0,
+       );
+    my $clientRow = $clients->row($addedId);
+    $clientRow->setReadOnly($hidden);
 
     $self->_setClientConf($name, %params);
 
     # config complete! we can set service to 1
     if ($params{service}) {
-        my $clientRow =  $clients->findRow(name => $name);
         $clientRow->elementByName('service')->setValue(1);
-        $clientRow->store();
     }
+    $clientRow->store();
 
     return $clients->client($name);
 }
@@ -1331,31 +1391,14 @@ sub _setClientConf
     my $serverPortAndProtocol = "$serverPort/" . $params{proto};
 
     my $clients   = $self->model('Clients');
-    my $clientRow =  $clients->findRow(name => $name);
+    my $clientRow = $clients->findRow(name => $name);
 
-    EBox::OpenVPN::Client->setCertificatesFilesForName(
-                                       $name,
-                                      caCertificate => $params{caCertificate},
-                                      certificate => $params{certificate},
-                                      certificateKey => $params{certificateKey},
-                                                      );
-
-    my $clientConfDir = EBox::OpenVPN::Client->privateDirForName($name);
-
-    
-
-    my @files = qw(caCertificate certificate certificateKey );
-    foreach my $f (@files) {
-
-# the destination must be firstly the same than the vlaue obtained with
-# tmpPath in the EBox::Type::File to assure the checks and then te final destination
-        my $tmpDest =  EBox::Config::tmp() . $f . '_path';
-        EBox::Sudo::root('cp ' . $params{$f} . " $tmpDest");
-
-        my $finalDest = "$clientConfDir/$f";
-        EBox::Sudo::root('cp ' . $params{$f} . " $finalDest");
-        EBox::Sudo::root("chmod 0400 $finalDest");
-    }
+    my $certPaths = EBox::OpenVPN::Client->setCertificatesFilesForName(
+        $name,
+        caCertificate => $params{caCertificate},
+        certificate => $params{certificate},
+        certificateKey => $params{certificateKey},
+       );
 
     # set config
     my $configRow =  $clientRow->subModel('configuration')->row();
@@ -1363,6 +1406,7 @@ sub _setClientConf
                        server => $server,
                        serverPortAndProtocol =>  $serverPortAndProtocol,
                        ripPasswd             => $params{ripPasswd},
+                       %{$certPaths},
                       );
 
     while (my ($attr, $value) = each %configToSet) {
@@ -1370,8 +1414,8 @@ sub _setClientConf
     }
     $configRow->store();
 
-    # remove leftover upload temprary files bz they arent needed more
-    foreach my $f (@files) {
+    # remove leftover upload temporary files bz they aren't needed anymore
+    foreach my $f (qw(caCertificate certificate certificateKey)) {
         my $path =  EBox::Config::tmp() . $f . '_path';
         EBox::Sudo::root("rm -rf $path");
     }
@@ -1412,7 +1456,9 @@ sub menu
 
     my $folder = new EBox::Menu::Folder(
                                         'name' => 'VPN',
-                                        'text' => __('VPN')
+                                        'text' => $self->printableName(),
+                                        'separator' => __('UTM'),
+                                        'order' => 330
                                        );
 
     $folder->add(
@@ -1431,45 +1477,96 @@ sub menu
     $root->add($folder);
 }
 
-sub summary
+sub openVPNWidget
 {
-    my ($self) = @_;
+    my ($self, $widget, $ovpn) = @_;
+    my $section = new EBox::Dashboard::Section($ovpn);
+    $widget->add($section);
+
+    my $titles = [__('Common name'),__('Address'), __('Connected since')];
+    my $rows = {};
+
+    my $path = $self->logDir() . '/' . 'status-' . $ovpn . '.log';
+
+    if (-f $path) {
+        my @status = read_file($path);
+        my $state = 0;
+
+        for my $line (@status) {
+            chomp($line);
+            if($state == 0) {
+                if($line =~m/^Common Name,/) {
+                    $state = 1;
+                }
+            } elsif($state == 1) {
+                my @fields = split(',', $line);
+                if(@fields != 5) {
+                    last;
+                }
+                my ($cname,$address,$recv,$sent,$date) = @fields;
+                $rows->{$cname} = [$cname,$address,$date];
+            }
+        }
+    }
+    my $ids = [sort keys %{$rows}];
+    $section->add(new EBox::Dashboard::List(undef, $titles, $ids, $rows,
+        __('No users connected to the VPN')));
+}
+
+sub openVPNDaemonsWidget
+{
+    my ($self, $widget) = @_;
 
     my @daemons = $self->daemons();
 
     if ( @daemons == 0 ) {
-        return undef;
+        return;
     }
 
-    my $summary = new EBox::Summary::Module(__('OpenVPN daemons'));
-
     foreach my $daemon (@daemons) {
         my @daemonSummary = $daemon->summary();
         @daemonSummary or next;
 
         my $name = shift @daemonSummary;
-        my $section = new EBox::Summary::Section($name);
+        my $section = new EBox::Dashboard::Section($daemon->name(),$name);
 
         while (@daemonSummary) {
             my ($valueName, $valueData) = splice(@daemonSummary, 0, 2);
-            $section->add(new EBox::Summary::Value($valueName, $valueData));
+            $section->add(new EBox::Dashboard::Value ($valueName, $valueData));
         }
-
-        $summary->add($section);
+        $widget->add($section);
     }
-
-    return $summary;
 }
 
-sub statusSummary
+# Method: widgets
+#
+# Overrides:
+#
+#      <EBox::Module::widgets>
+#
+sub widgets
 {
     my ($self) = @_;
-    return
-      new EBox::Summary::Status( 'openvpn', 
-                                 __('OpenVPN service'),
-                                 $self->userRunning, 
-                                 $self->service
-                               );
+    my @openvpns = $self->daemons();
+
+    my $widgets = {
+        'openvpndaemons' => {
+            'title' => __("OpenVPN daemons"),
+            'widget' => \&openVPNDaemonsWidget,
+            'default' => 1
+        }
+    };
+    foreach my $ovpn (@openvpns) {
+        unless ( $ovpn->internal() ) {
+            my $widget = {
+                'title' => $ovpn->name(),
+                'widget' => \&openVPNWidget,
+                'parameter' => $ovpn->name()
+               };
+            $widgets->{'vpn' . $ovpn->name()} = $widget;
+        }
+    }
+    return $widgets;
 }
 
 sub _backupClientCertificatesDir
@@ -1543,7 +1640,7 @@ sub tableInfo
                   connectionResetByServer => __('Server connection terminated'),
                  };
 
-    return {
+    return [{
             name => __('OpenVPN'),
             index => 'openvpn',
             titles => $titles,
@@ -1553,7 +1650,7 @@ sub tableInfo
             'filter' => ['daemon_name', 'from_ip', 'from_cert'],
             'events' => $events,
             'eventcol' => 'event'
-           };
+           }];
 
 }
 
